/***************************************************************************/
/**  @file      ring.h
 **  @brief     Acronym RING
 **  @details   Ring buffer macros.
 **  @copyright 2020 by EID, all rights reserved.
 **  @date
 **  @version   V1.0
 ***************************************************************************/

#ifndef RING_H_
#define RING_H_

#include <stdint.h>

//***************************************************************************
//                                Functions
//***************************************************************************

#define Ring_isEmpty(r)         (r.put == r.get)

#define Ring_isFull(r, dim)     (((r.put + 1)&((dim) - 1)) == r.get)

#define Ring_wr(r, dim, car)    (r.buf[r.put = (r.put + 1) & ((dim) - 1)] = car)

#define Ring_rd(r, dim)         (r.buf[r.get = (r.get + 1) & ((dim) - 1)])

#define Ring_ini(r)             (r.get = r.put = 0)

//NR 15/01/2020 -->
#define Ring_peek(r, dim)           (r.buf[(r.get + 1 ) & ((dim) - 1)])
//NR 15/01/2020 <--

#define Ring_new(name, IType, VType, size ) struct { IType put, get; VType buf[size]; } name

#endif /* RING_H_ */
/***************************************************************************/
